# Code of Conduct

For the code of conduct, see [HoloViz/HoloViz - CODE_OF_CONDUCT.md](https://github.com/holoviz/holoviz/blob/colorcet-gov/CODE_OF_CONDUCT.md).

The Colorcet Project’s equivalently named documents take precedence over any external materials referenced within this linked document above.
